pub enum ITIP20Errors {
Show 21 variants
InsufficientBalance(InsufficientBalance),
InsufficientAllowance(InsufficientAllowance),
SupplyCapExceeded(SupplyCapExceeded),
InvalidSupplyCap(InvalidSupplyCap),
InvalidPayload(InvalidPayload),
StringTooLong(StringTooLong),
PolicyForbids(PolicyForbids),
InvalidRecipient(InvalidRecipient),
ContractPaused(ContractPaused),
InvalidCurrency(InvalidCurrency),
InvalidQuoteToken(InvalidQuoteToken),
TransfersDisabled(TransfersDisabled),
InvalidAmount(InvalidAmount),
NoOptedInSupply(NoOptedInSupply),
Unauthorized(Unauthorized),
ProtectedAddress(ProtectedAddress),
InvalidToken(InvalidToken),
Uninitialized(Uninitialized),
InvalidTransferPolicyId(InvalidTransferPolicyId),
PermitExpired(PermitExpired),
InvalidSignature(InvalidSignature),
}Expand description
Container for all the ITIP20 custom errors.
Variants
InsufficientBalance(InsufficientBalance)
InsufficientAllowance(InsufficientAllowance)
SupplyCapExceeded(SupplyCapExceeded)
InvalidSupplyCap(InvalidSupplyCap)
InvalidPayload(InvalidPayload)
StringTooLong(StringTooLong)
PolicyForbids(PolicyForbids)
InvalidRecipient(InvalidRecipient)
ContractPaused(ContractPaused)
InvalidCurrency(InvalidCurrency)
InvalidQuoteToken(InvalidQuoteToken)
TransfersDisabled(TransfersDisabled)
InvalidAmount(InvalidAmount)
NoOptedInSupply(NoOptedInSupply)
ProtectedAddress(ProtectedAddress)
InvalidToken(InvalidToken)
Uninitialized(Uninitialized)
InvalidTransferPolicyId(InvalidTransferPolicyId)
PermitExpired(PermitExpired)
InvalidSignature(InvalidSignature)
Implementations
Sourceimpl ITIP20Errors
impl ITIP20Errors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP20Errors
impl ITIP20Errors
Sourcepub const fn insufficient_balance(
available: Uint<256, 4>,
required: Uint<256, 4>,
token: Address,
) -> ITIP20Errors
pub const fn insufficient_balance( available: Uint<256, 4>, required: Uint<256, 4>, token: Address, ) -> ITIP20Errors
Creates an error for insufficient token balance.
Sourcepub const fn insufficient_allowance() -> ITIP20Errors
pub const fn insufficient_allowance() -> ITIP20Errors
Creates an error for insufficient spending allowance.
Creates an error for unauthorized callers
Sourcepub const fn invalid_supply_cap() -> ITIP20Errors
pub const fn invalid_supply_cap() -> ITIP20Errors
Creates an error when minting would set a supply cap that is too large, or invalid.
Sourcepub const fn supply_cap_exceeded() -> ITIP20Errors
pub const fn supply_cap_exceeded() -> ITIP20Errors
Creates an error when minting would exceed supply cap.
Sourcepub const fn invalid_payload() -> ITIP20Errors
pub const fn invalid_payload() -> ITIP20Errors
Creates an error for invalid payload data.
Sourcepub const fn invalid_quote_token() -> ITIP20Errors
pub const fn invalid_quote_token() -> ITIP20Errors
Creates an error for invalid quote token.
Sourcepub const fn string_too_long() -> ITIP20Errors
pub const fn string_too_long() -> ITIP20Errors
Creates an error when string parameter exceeds maximum length.
Sourcepub const fn policy_forbids() -> ITIP20Errors
pub const fn policy_forbids() -> ITIP20Errors
Creates an error when transfer is forbidden by policy.
Sourcepub const fn invalid_recipient() -> ITIP20Errors
pub const fn invalid_recipient() -> ITIP20Errors
Creates an error for invalid recipient address.
Sourcepub const fn contract_paused() -> ITIP20Errors
pub const fn contract_paused() -> ITIP20Errors
Creates an error when contract is paused.
Sourcepub const fn invalid_currency() -> ITIP20Errors
pub const fn invalid_currency() -> ITIP20Errors
Creates an error for invalid currency.
Sourcepub const fn transfers_disabled() -> ITIP20Errors
pub const fn transfers_disabled() -> ITIP20Errors
Creates an error for transfers being disabled.
Sourcepub const fn invalid_amount() -> ITIP20Errors
pub const fn invalid_amount() -> ITIP20Errors
Creates an error for invalid amount.
Sourcepub const fn no_opted_in_supply() -> ITIP20Errors
pub const fn no_opted_in_supply() -> ITIP20Errors
Error for when opted in supply is 0
Sourcepub const fn protected_address() -> ITIP20Errors
pub const fn protected_address() -> ITIP20Errors
Error for operations on protected addresses (like burning FeeManager tokens)
Sourcepub const fn invalid_token() -> ITIP20Errors
pub const fn invalid_token() -> ITIP20Errors
Error when an address is not a valid TIP20 token
Sourcepub const fn invalid_transfer_policy_id() -> ITIP20Errors
pub const fn invalid_transfer_policy_id() -> ITIP20Errors
Error when transfer policy ID does not exist
Sourcepub const fn uninitialized() -> ITIP20Errors
pub const fn uninitialized() -> ITIP20Errors
Error when token is uninitialized (has no bytecode)
Sourcepub const fn permit_expired() -> ITIP20Errors
pub const fn permit_expired() -> ITIP20Errors
Error when permit signature has expired (block.timestamp > deadline)
Sourcepub const fn invalid_signature() -> ITIP20Errors
pub const fn invalid_signature() -> ITIP20Errors
Error when permit signature is invalid